LCWATrainingLoop
================

.. currentmodule:: pykeen.training

.. autoclass:: LCWATrainingLoop
   :show-inheritance:

   .. rubric:: Attributes Summary

   .. autosummary::

      ~LCWATrainingLoop.supports_slicing

   .. rubric:: Attributes Documentation

   .. autoattribute:: supports_slicing
